@@ -14,14 +14,15 @@
 #    limitations under the License.
 
 import copy
-import six
 
 from oslo_utils import importutils
 
 from mistralclient.api import httpclient
 from mistralclient.api.v2 import action_executions
 from mistralclient.api.v2 import actions
+from mistralclient.api.v2 import code_sources
 from mistralclient.api.v2 import cron_triggers
+from mistralclient.api.v2 import dynamic_actions
 from mistralclient.api.v2 import environments
 from mistralclient.api.v2 import event_triggers
 from mistralclient.api.v2 import executions
@@ -48,7 +49,7 @@ class Client(object):
         mistral_url = req.get('mistral_url')
         profile = req.get('profile')
 
-        if mistral_url and not isinstance(mistral_url, six.string_types):
+        if mistral_url and not isinstance(mistral_url, str):
             raise RuntimeError('Mistral url should be a string.')
 
         # If auth url was provided then we perform an authentication, otherwise
@@ -59,9 +60,10 @@ class Client(object):
         else:
             auth_response = {}
 
-        # If the session was None and we're using keystone auth, it will be
-        # created by the auth_handler.
-        session = auth_response.pop('session', None)
+        if session is None:
+            # If the session was None and we're using keystone auth, it will be
+            # created by the auth_handler.
+            session = auth_response.pop('session', None)
 
         req.update(auth_response)
 
@@ -86,6 +88,11 @@ class Client(object):
         self.event_triggers = event_triggers.EventTriggerManager(http_client)
         self.environments = environments.EnvironmentManager(http_client)
         self.action_executions = action_executions.ActionExecutionManager(
-            http_client)
+            http_client
+        )
         self.services = services.ServiceManager(http_client)
         self.members = members.MemberManager(http_client)
+        self.code_sources = code_sources.CodeSourceManager(http_client)
+        self.dynamic_actions = dynamic_actions.DynamicActionManager(
+            http_client
+        )
